//
// /*
// * Copyright 2009-2021 Alibaba Cloud All rights reserved.
// *
// * Licensed under the Apache License, Version 2.0 (the "License");
// * you may not use this file except in compliance with the License.
// * You may obtain a copy of the License at
// *
// *      http://www.apache.org/licenses/LICENSE-2.0
// *
// * Unless required by applicable law or agreed to in writing, software
// * distributed under the License is distributed on an "AS IS" BASIS,
// * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// * See the License for the specific language governing permissions and
// * limitations under the License.
// *
  

#import "CSVParser.h"
#import "ImageData.h"

@implementation CSVParser

- (NSArray<ImageData *> *)parseCSVFile:(NSString *)filePath {
    NSError *error;
    NSString *fileContents = [NSString stringWithContentsOfFile:filePath encoding:NSUTF8StringEncoding error:&error];
    
    if (error) {
        NSLog(@"Error reading file: %@", error.localizedDescription);
        return nil;
    }
    
    NSMutableArray<ImageData *> *imageDataArray = [NSMutableArray array];
    NSArray *lines = [fileContents componentsSeparatedByString:@"\n"];
    
    for (NSString *line in lines) {
        if ([line length] == 0 || [line isEqualToString:@"object,url"]) {
            continue;
        }
        
        NSArray *components = [line componentsSeparatedByString:@","];
        if ([components count] == 2) {
            NSString *object = components[0];
            NSString *url = components[1];
            ImageData *imageData = [[ImageData alloc] initWithObject:object url:url];
            [imageDataArray addObject:imageData];
        }
    }
    
    return [imageDataArray copy];
}
@end
