#import "ImageDownloadManager.h"
#import <SDWebImage/SDWebImage.h>

@implementation ImageDownloadManager

+ (instancetype)sharedManager {
  static ImageDownloadManager *manager = nil;
  static dispatch_once_t onceToken;
  dispatch_once(&onceToken, ^{
    manager = [[ImageDownloadManager alloc] init];
  });
  return manager;
}

- (void)downloadImagesWithArray:(NSArray<ImageData *> *)images
                     completion:(void (^)(BOOL success))completion
                progressHandler:(void (^)(NSString *status))progressHandler {
  __block NSInteger remainingDownloads = images.count;
  __block NSMutableDictionary *progressByURL = [NSMutableDictionary new];

  for (ImageData *imageData in images) {
    NSURL *url = [NSURL URLWithString:imageData.url];
    progressByURL[url] = @0.0;

    [[SDWebImageDownloader sharedDownloader] downloadImageWithURL:url
        options:0
        progress:^(NSInteger receivedSize, NSInteger expectedSize,
                   NSURL *_Nullable targetURL) {
          CGFloat progress = (CGFloat)receivedSize / (CGFloat)expectedSize;

          @synchronized(self) {
            progressByURL[targetURL] = @(progress);

            // Calculate total progress as average of all image progress
            CGFloat totalProgress = 0;
              for (NSNumber *value in progressByURL.allValues) {
              totalProgress += value.floatValue;
            }
            totalProgress = (totalProgress / images.count) * 100;

            if (progressHandler) {
              dispatch_async(dispatch_get_main_queue(), ^{
                NSString *status = [NSString
                    stringWithFormat:@"下载中... %.0f%%", totalProgress];
                progressHandler(status);
              });
            }
          }
        }
        completed:^(UIImage *image, NSData *data, NSError *error,
                    BOOL finished) {
          if (!error) {
            imageData.width = image.size.width;
            imageData.height = image.size.height;
          }
          remainingDownloads--;

          if (remainingDownloads == 0) {
            if (completion) {
              dispatch_async(dispatch_get_main_queue(), ^{
                completion(YES);
              });
            }
          }
        }];
  }
}

@end
